/**
 * This document provide basic idea on how the adapter should behave in case if the sensor
 * is used in a casting environment.
 */


//----------------------------------- SENDER SIDE---------------------------------------//
var castPlayer = new CastPlayer();

window['__onGCastApiAvailable'] = function (isAvailable) {
	if (isAvailable) {
		castPlayer.initializeCastPlayer();
	}
};

var streamingSensor;

function trackVideo() {
	console.log("trackVideo called");

	if (typeof (streamingSensor) == 'undefined') {
		streamingSensor = new SpringStreams('test-barb-uk');
		streamingSensor.debug = function (v) {
			console.log('Sensor debug output: ', v);
		}
	}
	streamingSensor.unload();

	var vid = document.getElementById("video_element");
	var stream = vid.src;
	if (cast && cast.framework && castPlayer.remotePlayer.isConnected) {
		stream = castPlayer.remotePlayer.title;
	}

	var desc = {
		"sx": window.innerWidth,
		"sy": window.innerHeight,
		"stream": stream
	};

	var adapter = {
		"getMeta": function (id) {
			return {
				"pl": "ChromeCastTestPlayer",
				"plv": "1.0.0",
				"sx": vid.videoWidth,
				"sy": vid.videoHeight
			}
		},
		"getPosition": function (id) {
			return Math.round(vid.currentTime);

		},
		"getDuration": function (id) {
			return Math.round(vid.duration);
		}
	}
	// Calling Track method of Sensor
	var handle = streamingSensor.track("ChromeCastTestPlayer", desc, adapter);
}

window.onbeforeunload = function (e) {
	if (typeof (streamingSensor) !== 'undefined') {
		streamingSensor.unload();
	}
}

//------------------------------------ SENDER SIDE ENDS ------------------------------------//

/**
 * This code provide basic idea on how the adapter should behave in case if the sensor
 * is used in a casting environment as custom reciever.
 */

//----------------------------------- RECEIVER SIDE --------------------------------------//


var sensors;
var pageContext_springstreams = new PageContext();
SpringStreams.prototype.setPageContext(pageContext_springstreams);
if (typeof sensors == "undefined")
	// Checking if the instance of the sensor is already created. If not we are creating one. This ensures that we will instantiate spring sensor only once!!
	sensors = new SpringStreams("box30107", "2cnt.net");
const context = cast.framework.CastReceiverContext.getInstance();
//Get player manager object 
const playerManager = context.getPlayerManager();
// intercept the LOAD request to be able to read in a contentId and get data
playerManager.setMessageInterceptor(
	cast.framework.messages.MessageType.LOAD,
	loadRequestData => {
		if (loadRequestData.media && loadRequestData.media.contentId) {
			console.log(loadRequestData.media);
			var desc = {
				sx: window.innerWidth,
				sy: window.innerHeight,
				stream: playerManager.getMediaInformation().contentId
			};

			handle = sensors.track("testplayer", desc, adapter); // Calling Track method of Sensor !!
			sensors.debug = function (v) {
				//if(debugFlag)
				console.log("Request:", v);
				var test = "<p>" + v + "</p>";
				//div.insertAdjacentHTML('beforeend', test);
			};
		}
		return loadRequestData;
	}
);

context.start();

/*------------------------------------------Implementing stream adapter ---------------------------------- */
var adapter = {
	getMeta: function (id) {
		return {
			pl: "testPlayer1008",
			plv: "1.0.0",
			sx: window.innerWidth,
			sy: window.innerHeight
		};
	},
	getPosition: function (id) {
		// if(debugFlag)
		// console.log("Pos: " + Math.round(vid.currentTime));
		return Math.round(playerManager.getCurrentTimeSec());
	},
	getDuration: function (id) {
		// if(debugFlag)
		console.log(
			"Duration: " + Math.round(playerManager.getDurationSec())
		);
		return Math.round(playerManager.getDurationSec());
	}
};

window.onbeforeunload = function (e) {
	sensors.unload();
};

 //----------------------------------- RECEIVER SIDE ENDS --------------------------------------//